summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TLiteral.php
diff options
context:
space:
mode:
authorFabio Bas <ctrlaltca@gmail.com>2015-01-25 20:04:57 +0100
committerFabio Bas <ctrlaltca@gmail.com>2015-01-25 20:04:57 +0100
commite4999b25052d1ad9400a0f9fd5289a49eea1bddc (patch)
tree50e9b819fc3326cf08e882b648f8dafc8fec3fa4 /framework/Web/UI/WebControls/TLiteral.php
parent5230f8f8a86fc1ae5d90f8c74ae65c93e197502b (diff)
More namespace changes
Changed version to 3.2.99; Attempt at fixing autoloading fixed enough namespaces to have some demos running
Diffstat (limited to 'framework/Web/UI/WebControls/TLiteral.php')
-rw-r--r--framework/Web/UI/WebControls/TLiteral.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/framework/Web/UI/WebControls/TLiteral.php b/framework/Web/UI/WebControls/TLiteral.php
index b9bc65ce..dc15ad0c 100644
--- a/framework/Web/UI/WebControls/TLiteral.php
+++ b/framework/Web/UI/WebControls/TLiteral.php
@@ -10,6 +10,7 @@
*/
namespace Prado\Web\UI\WebControls;
+use Prado\TPropertyValue;
/**
* TLiteral class
@@ -31,7 +32,7 @@ namespace Prado\Web\UI\WebControls;
* @package Prado\Web\UI\WebControls
* @since 3.0
*/
-class TLiteral extends TControl implements IDataRenderer
+class TLiteral extends \Prado\Web\UI\TControl implements \Prado\IDataRenderer
{
/**
* @return string the static text of the TLiteral
@@ -52,7 +53,7 @@ class TLiteral extends TControl implements IDataRenderer
/**
* Returns the static text of the TLiteral.
* This method is required by {@link IDataRenderer}.
* It is the same as {@link getText()}.
* @return string the static text of the TLiteral
* @see getText
@@ -65,7 +66,7 @@ class TLiteral extends TControl implements IDataRenderer
/**
* Sets the static text of the TLiteral.
* This method is required by {@link IDataRenderer}.
* It is the same as {@link setText()}.
* @param string the static text of the TLiteral
* @see setText
@@ -52,7 +53,7 @@ class TLiteral extends TControl implements IDataRenderer
/**
* Returns the static text of the TLiteral.
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link getText()}.
* @return string the static text of the TLiteral
@@ -65,7 +66,7 @@ class TLiteral extends TControl implements IDataRenderer
/**
* Sets the static text of the TLiteral.
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link setText()}.
* @param string the static text of the TLiteral